User Guide
==========

.. toctree::
   :maxdepth: 2

   conformal_inference
   conformalization_strategies
   weighted_conformal
   fdr_control
   batch_evaluation
   streaming_evaluation
   statistical_concepts
   logging
   best_practices
   troubleshooting
